//
//  AASBasicInfoFile.h
//
//  Created by Andreas Schwarz on Thu Apr 18 2002.
//  Copyright (c) 2001-2009 Andreas Schwarz @ immaterial.
//


#import <Cocoa/Cocoa.h>
#import "AASFile.h"

/* The AASBasicInfoFile is an AASFile subclass that contains some extra basic information about a file, such as the display name and whether it is a directory, application, package, and, if it is an alias or a symbolic link, the file it points to. */


/* Keys for archive dictionaries */
extern NSString *AASArchiveIsAliasKey;	// Will return an NSNumber BOOL value - YES if the file was a symbolic link or alias, NO if it was a 'real' file 



@interface AASBasicInfoFile : AASFile {
    char isApplication;
    char isVolumesDirectory;
    char isRootDirectory;
    char isDirectory;
    char isPackage;
    char isInvisible;
	char isAlias;
    
    FSRef resolvedFSRef;
    char resolvedFSRefIsValid;
    char resolvedIsDirectory;
	id resolvedFile;
    
    NSString *fileName;
    NSString *displayName;
	NSString *resolvedPath;
    CFURLRef resolvedURL;
    CFStringRef UTI;
    CFStringRef resolvedUTI;
}

/* Returns the true file name of the file (including the extension).  This is really only the last path component, so it may not work properly on things like volume names. */
- (NSString *)fileName;

/* Returns the display name of the file (this takes into account whether or not the file extension is hidden, and returns the proper name for volumes (like the root volume). */
- (NSString *)displayName;



/* If this file is an alias/symlink, this returns the path to whatever file the alias is pointing to.  Otherwise, it returns the path to this file. */
- (NSString *)resolvedPath;
/* If this file is an alias/symlink, this returns the URL to whatever file the alias is pointing to.  Otherwise, it returns the URL to this file. */
- (NSURL *)resolvedURL;
/* If the file is an alias/symlink, returns a pointer to an FSRef for the file the alias points to.  Otherwise returns a pointer to the FSRef for the file itself.  Might be null. */
- (FSRef *)resolvedFSRef;
/* If the file is an alias/symlink, returns a AASBasicInfoFile instance (or subclass of the same class as the reciever) for the file the alias points to.  Otherwise returns itself. */
- (id)resolvedFile;


/* Returns the UTI of the file. */
- (CFStringRef)uti;
/* If the file is an alias/symlink, returns the UTI for the file the alias points to.  Otherwise returns its own UTI. */
- (CFStringRef)resolvedUTI;


// Can be called to re-check the resolved FSRef in case this file is an alias and the file it pointed to is now gone.
// Returns YES if the file is an alias/symlink and NO otherwise
// Subclasses will want to implement this (make sure to call super) to reset any information that may hinge on what the alias points to
- (BOOL)resetAliasStatus;



/* Returns whether this file is an alias file. */
- (BOOL)isAlias;

/* A shortcut to see whether the file is an alias/symlink or a "real" file. */
- (BOOL)isRealFile;




/* Returns whether this file is an application.  This includes if it is an alias or symlink to an application. */
- (BOOL)isApplication;

/* Returns whether this file is a directory.  This includes if it is an alias or symlink to a directory.  It excludes package. */
- (BOOL)isDirectory;

/* Returns whether this file is a package.  This includes if it is an alias or symlink to a package. */
- (BOOL)isPackage;

/* The Volumes directory can be used as a cheap and dirty way to fake a Finderlike "Computer" directory, so knowing whether or not a directory is the volumes directory might be useful.  It is needed for these reasons by the above displayName and fileName methods. */
- (BOOL)isVolumesDirectory;

/* Returns whether this file is the root directoy (path "/"). */
- (BOOL)isRootDirectory;

/* Returns whether this file is invisible. (Special cases: /net/ and /home/ are returned as invisible though LaunchServices does not identify them as such. The Finder, however, does not show these items.) */
- (BOOL)isInvisible;

@end
