//
//  AASFileFilter.h
//  AASFilesystemTools
//
//  Created by Andreas Schwarz on 3/11/08.
//  Copyright (c) 2001-2009 Andreas Schwarz @ immaterial.
//

/* Objects of this class are used to determine whether or not an AASFile (or subclass) object should be included or excluded from a set. This class merely returns 'YES' every time, which would include all file objects in the set. Subclasses can override the filter method to exclude files however they please. For example, if you are using an AASFileLoader to recursively load AASBasicInfoFile objects for a given directory tree, you can pass the AASFileLoader object an instance of the AASFileFilter subclass AASVisibleFileFilter which returns NO if a file is invisible, to keep invisible files out of the returned array. */

#import <Cocoa/Cocoa.h>


@interface AASFileFilter : NSObject {

}

/* Convenience constructor method (autoreleased). */
+ (id)filter;

/* Subclasses should override this method however they see fit to include or exclude the file based on certain criteria. The default implementation returns YES for all objects. */
- (BOOL)shouldIncludeFile:(AASFile *)file;

@end
