//
//  AASFileManager.h
//
//  Created by andreas on Fri Nov 16 2001.
//  Copyright (c) 2001-2009 Andreas Schwarz @ immaterial. 
//
//  OS X 10.5 or later required.


//  Known issues: subscribing/getting file objects for a directory is not thread-safe. Need to add some locks and stuff.



#import <Foundation/Foundation.h>
#import <CoreServices/CoreServices.h>

@class AASDirectorySubscription;
@class AASFile;

@interface AASFileManager : NSObject {
	NSOperationQueue *operationQueue;
	NSOperationQueue *utilityQueue;
	
    NSTimer *timer;
    CFMutableArrayRef directories;
    CFMutableDictionaryRef directoriesDict;
    
    CFMutableArrayRef removedDirectoriesReleaseTimers;
    
    Class fileClass;
    BOOL asynchronous;
    BOOL madeFiles;
    BOOL hadSubscribers;
    
    float pollingInterval;
    BOOL paused;
}



/* Returns the AASFileManager instance (AASFileManager is a singleton). Before you use it you must set certain values, such as the file class (file class specifies what class you want the AASFileManager and AASDirectorySubscription objects to use for tracking files - AASFile [the default] or a subclass).  Filesystem tracking doesn't actually begin until there is at least one subscription. */
+ (AASFileManager *)defaultFileManager;


/* Call this as your program exits to gracefully clean up. Do not attempt to use the AASFileManager instance after this. */
- (void)shutdown;


/* The following set: method must be called before any subscriber asks to track a directory or any method is called that creates an object based on the file class. If you do this correctly, the methods will return YES. If you attempt to set them afterward, they will return NO. */

/* Returns the class of file objects the AASFileManager and its AASDirectorySubscription instances are using. Default is AASFile. */
- (Class)fileClass;
/* Subclassing the AASFile class can be useful if you want to have more information about each file in one convenient "central" location; see AASBasicInfoFile as an example.  There is only one AASFile object per file in the file system. Default is AASFile. */
- (BOOL)setFileClass:(Class)class;


/* The operation queue used for loading files. Has a very high maximum concurrent operation count. */
- (NSOperationQueue *)operationQueue;

/* The operation queue used various file operations. Uses a maximum concurrent operation count of 4 * number of processors on the machine. */
- (NSOperationQueue *)utilityQueue;


@end
