//
//  AASLoadingOperation.h
//  AASFilesystemTools
//
//  Created by Andreas Schwarz on 3/12/08.
//  Copyright (c) 2001-2009 Andreas Schwarz @ immaterial.
//

/* AASLoadingOperation is a subclass of NSOperation that has some basic support for an array in which to load objects from the worker thread, and locks to safely work with that array in both the worker thread and the client thread. It is used as a basis for the AASFileLoadOperation class, but can be useful as the basis for any number of similar operations. Like NSOperation, AASLoadingOperation cannot be used on its own, it must be subclassed. */

#import <Cocoa/Cocoa.h>


@interface AASLoadingOperation : NSOperation {
	NSLock *loadingArrayLock;
	NSMutableArray *loadingArray;
}


/* Set or get the lock to use when manipulating the loading array and events array. Do not set after the operation has been added to an operation queue. */
@property(retain) NSLock *loadingArrayLock;

/* Set or get the array for that the operation is filling with objects. Do not set after the operation has been added to an operation queue, and always use the loadingArrayLock when accessing or modifying the array until the operation is finished. */
@property(retain) NSMutableArray *loadingArray;


@end
