//
//  GBPrefsData.h
//  gBrowser
//
//  Created by Andreas Schwarz on Mon Dec 24 2001.
//  Copyright (c) 2001 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <GBBasicsKit/GBBasicsKit.h>

@class GBFile;

@interface GBPrefsData : NSObject {
    NSUndoManager *undoManager;
    NSNotificationCenter *notificationCenter;
    NSDocument *document;

    BOOL doNotAutosave;

    // Preferences    
    BOOL infoCreationValue;
    BOOL infoColorModelValue;
    BOOL infoDimensionsValue;
    BOOL infoMegapixelsValue;
    BOOL infoICCValue;
    BOOL infoFileNameValue;
    BOOL infoFileSizeValue;
    BOOL infoFileTypeValue;
    BOOL infoImageSizeValue;
    BOOL infoKindValue;
    BOOL infoModificationValue;
    BOOL infoResolutionValue;
    
    BOOL clusterSlideshowFolders;    
    BOOL slideshowFoldersInMenus;    
    BOOL useSlideshowFolderGrouping;
    BOOL loopSlideshowTimer;
    BOOL autohideSlideshowController;

    BOOL collapsePreviewGenWindow;
    BOOL manualPreviewGenOnlyIfDifferent;
    BOOL previewGenStripsForks;
    
    BOOL imageViewerOpensFullscreen;
    BOOL imageViewerOpenOnLoad;
    BOOL imageViewerRememberPosition;
    
    BOOL saveSlideshowChanges;
    
    BOOL previewAutoIfDiffValue;
    BOOL separatePreviewCheckboxValue;
    
    BOOL imageShadowsCheckboxValue;
    BOOL textShadowsCheckboxValue;
    
    BOOL fileListUsesGenericIcons;
    
    BOOL showSlideshowController;
    BOOL useSlideshowTimer;

    BOOL highQualityThumbnailScaling;
    BOOL lowQualityOnTheFly;
    
    BOOL renameOnEnterOnlyInFileList;
    BOOL renameOnEnterOnlyInPreviewPane;
    
    BOOL reverseSlideshowSort;
    
    BOOL openImagesExternally;

	
	GBFileFilterTypes sidebarFileFilter;
	GBFileFilterTypes thumbnailPaneFileFilter;
	GBFileFilterTypes thumbnailPaneFolderFilter;
	
	
    BOOL autoExpandFileListDuringDrops;
    BOOL showFileCountInFileList;
        
    BOOL collapseSlideshowController;
    
    BOOL alignThumbnailsToBottom;
    
    GBOpenImageInOptions openInAppRadioValue;
    
    GBImageSharpenOptions previewSharpenValue;
    GBImageSharpenOptions previewPresharpenValue;
    
    GBScreenOptions imageViewerScreen;
    GBScreenOptions slideshowScreen;
    
    GBOpenOptions imageViewerDisplayType;
    GBOpenOptions slideshowDisplayType;
    
    GBSlideshowSortTypes slideshowSortType;
    
    GBOpenSizeOptions imageViewerDisplayPercentage;
    GBOpenSizeOptions slideshowDisplayPercentage;
    
    GBFile *openInAppFile;
    
    NSString *prefsWindowFrameString;
    NSString *browserWindowFrameString;
    NSString *imageViewerFrameString;
    
    NSString *statusString;
    
    int browserPreviewSizeValue;
    int previewGenerationSizeValue;
    
    int thumbnailQuality;
    
    int fileListWidth;
    int fileListSpacing;
    
    int cellPaddingValue;
    int horizontalCellSpacingValue;
    int verticalCellSpacingValue;
    
    int imageOutlineThickness;
    
    int fileListFontHeight;
    
    NSColor *previewCellBackgroundColor;
    NSColor *previewCellTextColor;
    NSColor *previewCellTextShadowColor;
    NSColor *previewPaneBackgroundColor;
    NSColor *fileListBackgroundColor;
    NSColor *fileListAltBackgroundColor;
    NSColor *fileListTextColor;

    NSColor *outlineImagesColor;
    NSColor *thumbnailShadowColor;

    NSColor *imageViewerBackgroundColor;
    NSColor *slideshowBackgroundColor;
    NSColor *slideshowTextColor;
    
    float slideshowTimerSeconds;
    
    BOOL outlineImagesCheckboxValue;
    
    int fadeSlideshowControlsValue;
    
    BOOL recursiveSlideshow;
    BOOL slideshowShowsFilename;
    
    BOOL minimizeFileList;
    
    //BOOL loadPreviewImmediately;
    BOOL createPreviewOnTheFly;

    BOOL fileListAlternatesBackground;
    BOOL reversePreviewsSort;
    BOOL reverseFileListSort;
    
    GBPreviewCellBorderTypes previewCellBorder;
    int fileListIconSize;
    
    GBPositions slideshowFilenamePosition;
        
    GBOpenOptions openOptionsValue;
    GBOpenSizeOptions openSizeOptionsValue;
    GBSortTypes previewsSortType;
    GBSortTypes fileListSortType;
	
	
    
    NSArray *currentFileListSelectedFiles;
    
    NSArray *currentFileListExpandedFiles;
    
    NSArray *openWithFiles;
    NSArray *moveToFiles;
    
    NSDictionary *toolbarConfiguration;
    NSDictionary *toolbarAliasDataDict;
    
    GBFile *fileListRootFile;
    
    NSFont *viewFont;
    NSFont *fileListFont;
    NSFont *slideshowTextFont;
}


// Initialization
- (id)initWithUndoManager:(NSUndoManager *)um forDocument:(NSDocument *)doc;

- (void)updateChangeCount;
- (NSDocument *)document;

- (NSUndoManager *)undoManager;

- (void)setDoNotAutosave:(BOOL)value;

    // Prefs
- (BOOL)setFileListRoot:(GBFile *)file;
- (GBFile *)getFileListRoot;

- (void)setCurrentFileListSelectedFiles:(NSArray *)files;
- (void)setCurrentFileListSelectedFilesNoNotification:(NSArray *)files;
- (NSArray *)getCurrentFileListSelectedFiles;

- (void)setCurrentFileListExpandedFiles:(NSArray *)expandedFiles;
- (NSArray *)getCurrentFileListExpandedFiles;

- (NSString *)getRootFolderName;

- (void)setImageViewerDisplayType:(GBOpenOptions)value;
- (GBOpenOptions)imageViewerDisplayType;
- (void)setSlideshowDisplayType:(GBOpenOptions)value;
- (GBOpenOptions)slideshowDisplayType;

- (BOOL)minimizeFileList;
- (void)setMinimizeFileList:(BOOL)minimize;

- (void)setHighQualityThumbnailScaling:(BOOL)value;
- (BOOL)highQualityThumbnailScaling;

- (void)setLowQualityOnTheFly:(BOOL)value;
- (BOOL)lowQualityOnTheFly;

- (void)setPreviewsSortType:(GBSortTypes)sortType;
- (GBSortTypes)getPreviewsSortType;
- (void)setReversePreviewsSort:(BOOL)value;
- (BOOL)reversePreviewsSort;

- (void)setAlignThumbnailsToBottom:(BOOL)value;
- (BOOL)alignThumbnailsToBottom;

- (void)setSlideshowSortType:(GBSlideshowSortTypes)sortType;
- (GBSortTypes)slideshowSortType;
- (void)setReverseSlideshowSort:(BOOL)value;
- (BOOL)reverseSlideshowSort;

- (void)setCollapseSlideshowController:(BOOL)value;
- (BOOL)collapseSlideshowController;

- (void)setThumbnailQuality:(int)quality;
- (int)thumbnailQuality;

- (BOOL)imageViewerOpensFullscreen;
- (void)setImageViewerOpensFullscreen:(BOOL)value;
- (BOOL)imageViewerOpenOnLoad;
- (void)setImageViewerOpenOnLoad:(BOOL)value;
- (BOOL)imageViewerRememberPosition;
- (void)setImageViewerRememberPosition:(BOOL)value;
- (void)setImageViewerFrameString:(NSString *)frameString;
- (NSString *)imageViewerFrameString;

- (void)setImageViewerDisplayPercentage:(GBOpenSizeOptions)value;
- (GBOpenSizeOptions)imageViewerDisplayPercentage;
- (void)setSlideshowDisplayPercentage:(GBOpenSizeOptions)value;
- (GBOpenSizeOptions)slideshowDisplayPercentage;
- (void)setRecursiveSlideshow:(BOOL)value;
- (BOOL)recursiveSlideshow;
- (void)setClusterSlideshowFolders:(BOOL)value;
- (BOOL)clusterSlideshowFolders;

- (void)setSaveSlideshowChanges:(BOOL)value;
- (BOOL)saveSlideshowChanges;

- (void)setUseSlideshowFolderGrouping:(BOOL)value;
- (BOOL)useSlideshowFolderGrouping;
- (void)setLoopSlideshowTimer:(BOOL)value;
- (BOOL)loopSlideshowTimer;
- (float)slideshowTimerSeconds;
- (void)setSlideshowTimerSeconds:(float)value;
- (void)setUseSlideshowTimer:(BOOL)value;
- (BOOL)useSlideshowTimer;
- (void)setSlideshowFoldersInMenus:(BOOL)value;
- (BOOL)slideshowFoldersInMenus;
- (void)setAutohideSlideshowController:(BOOL)value;
- (BOOL)autohideSlideshowController;

- (void)setShowFileCountInFileList:(BOOL)value;
- (BOOL)showFileCountInFileList;

- (void)setRenameOnEnterOnlyInFileList:(BOOL)value;
- (BOOL)renameOnEnterOnlyInFileList;
- (void)setRenameOnEnterOnlyInPreviewPane:(BOOL)value;
- (BOOL)renameOnEnterOnlyInPreviewPane;

- (void)setCollapsePreviewGenWindow:(BOOL)value;
- (BOOL)collapsePreviewGenWindow;

- (void)setFileListSpacing:(int)value;
- (int)fileListSpacing;

- (void)setSlideshowShowsFilename:(BOOL)value;
- (BOOL)slideshowShowsFilename;

- (void)setFileListSortType:(GBSortTypes)sortType;
- (GBSortTypes)getFileListSortType;
- (void)setReverseFileListSort:(BOOL)value;
- (BOOL)reverseFileListSort;

- (void)setPreviewSharpenValue:(GBImageSharpenOptions)sharpen;
- (GBImageSharpenOptions)getPreviewSharpenValue;
    
- (void)setOpenOptionsValue:(GBOpenOptions)value;
- (GBOpenOptions)getOpenOptionsValue;

- (void)setOpenSizeOptionsValue:(GBOpenSizeOptions)value;
- (GBOpenSizeOptions)getOpenSizeOptionsValue;

- (void)setPrefsWindowFrameString:(NSString *)frameString;
- (NSString *)getPrefsWindowFrameString;

- (void)setBrowserWindowFrameString:(NSString *)frameString;
- (NSString *)getBrowserWindowFrameString;

- (void)setShowSlideshowController:(BOOL)value;
- (BOOL)showSlideshowController;

- (void)setPreviewAutoIfDiffValue:(BOOL)value;
- (BOOL)getPreviewAutoIfDiffValue;

//- (void)setLoadPreviewImmediately:(BOOL)value;
//- (BOOL)loadPreviewImmediately;
- (void)setCreatePreviewOnTheFly:(BOOL)value;
- (BOOL)createPreviewOnTheFly;

- (void)setManualPreviewGenOnlyIfDifferent:(BOOL)value;
- (BOOL)manualPreviewGenOnlyIfDifferent;
- (void)setPreviewGenStripsForks:(BOOL)value;
- (BOOL)previewGenStripsForks;


- (void)setSidebarFileFilter:(GBFileFilterTypes)filter;
- (GBFileFilterTypes)sidebarFileFilter;
- (void)setThumbnailPaneFileFilter:(GBFileFilterTypes)filter;
- (GBFileFilterTypes)thumbnailPaneFileFilter;
- (void)setThumbnailPaneFolderFilter:(GBFileFilterTypes)filter;
- (GBFileFilterTypes)thumbnailPaneFolderFilter;


/*
- (void)setPreviewPaneImagesOnly:(BOOL)value;
- (BOOL)previewPaneImagesOnly;
- (void)setPreviewPaneFoldersImagesOnly:(BOOL)value;
- (BOOL)previewPaneFoldersImagesOnly;
- (void)setPreviewPaneFoldersOnly:(BOOL)value;
- (BOOL)previewPaneFoldersOnly;
- (void)setFileListFoldersOnly:(BOOL)value;
- (BOOL)fileListFoldersOnly;
- (void)setFileListFoldersImagesOnly:(BOOL)value;
- (BOOL)fileListFoldersImagesOnly;
*/



- (void)setImageViewerBackgroundColor:(NSColor *)color;
- (NSColor *)getImageViewerBackgroundColor;
- (void)setSlideshowBackgroundColor:(NSColor *)color;
- (NSColor *)getSlideshowBackgroundColor;
- (void)setSlideshowTextColor:(NSColor *)color;
- (NSColor *)slideshowTextColor;

- (NSColor *)thumbnailShadowColor;
- (void)setThumbnailShadowColor:(NSColor *)color;

- (void)setFileListAlternatesBackground:(BOOL)value;
- (BOOL)getFileListAlternatesBackground;

- (void)setOutlineImagesCheckboxValue:(BOOL)value;
- (BOOL)getOutlineImagesCheckboxValue;

- (void)setImageShadowsCheckboxValue:(BOOL)value;
- (BOOL)getImageShadowsCheckboxValue;

- (void)setTextShadowsCheckboxValue:(BOOL)value;
- (BOOL)getTextShadowsCheckboxValue;

- (void)setAutoExpandFileListDuringDrops:(BOOL)value;
- (BOOL)autoExpandFileListDuringDrops;

- (void)setPreviewPresharpenValue:(GBImageSharpenOptions)sharpen;
- (GBImageSharpenOptions)getPreviewPresharpenValue;

- (void)setOutlineImagesColor:(NSColor *)color;
- (NSColor *)getOutlineImagesColor;

- (void)setCellPaddingValue:(int)value;
- (int)getCellPaddingValue;
- (void)setHorizontalCellSpacingValue:(int)value;
- (int)horizontalCellSpacingValue;
- (void)setVerticalCellSpacingValue:(int)value;
- (int)verticalCellSpacingValue;

- (NSColor *)getPreviewCellBackgroundColor;
- (void)setPreviewCellBackgroundColor:(NSColor *)color;
- (NSColor *)getPreviewCellTextColor;
- (void)setPreviewCellTextColor:(NSColor *)color;
- (NSColor *)getPreviewCellTextShadowColor;
- (void)setPreviewCellTextShadowColor:(NSColor *)color;
- (NSColor *)getPreviewPaneBackgroundColor;
- (void)setPreviewPaneBackgroundColor:(NSColor *)color;

- (NSColor *)getFileListBackgroundColor;
- (void)setFileListBackgroundColor:(NSColor *)color;
- (NSColor *)getFileListAltBackgroundColor;
- (void)setFileListAltBackgroundColor:(NSColor *)color;
- (NSColor *)getFileListTextColor;
- (void)setFileListTextColor:(NSColor *)color;

- (void)setFadeSlideshowControlsValue:(int)value;
- (int)fadeSlideshowControlsValue;

- (GBPreviewCellBorderTypes)getPreviewCellBorder;
- (void)setPreviewCellBorder:(GBPreviewCellBorderTypes)border;


- (void)setOpenWithFiles:(NSArray *)files;
- (NSArray *)openWithFiles;
- (void)setMoveToFiles:(NSArray *)files;
- (NSArray *)moveToFiles;


- (int)getFileListIconSize;
- (void)setFileListIconSize:(int)value;

- (void)setSlideshowTextFont:(NSFont *)font;
- (NSFont *)slideshowTextFont;
- (NSString *)slideshowTextFontName;
- (NSString *)slideshowTextFontSizeString;
- (NSString *)slideshowTextFontDisplayName;
- (void)setSlideshowTextFontName:(NSString *)name withSize:(float)size;

- (void)setViewFont:(NSFont *)font;
- (NSFont *)getViewFont;
- (NSString *)getViewFontName;
- (NSString *)getViewFontSizeString;
- (NSString *)getViewFontDisplayName;
- (int)getViewFontHeight;

- (NSFont *)defaultFont;
- (NSString *)getFileListFontName;
- (NSString *)getFileListFontSizeString;
- (NSString *)getFileListFontDisplayName;

- (void)setImageViewerScreen:(GBScreenOptions)screen;
- (GBImageSharpenOptions)imageViewerScreen;
- (void)setSlideshowScreen:(GBScreenOptions)screen;
- (GBImageSharpenOptions)slideshowScreen;
- (void)setSlideshowFilenamePosition:(GBPositions)pos;
- (GBPositions)slideshowFilenamePosition;

- (void)setBrowserPreviewSizeValue:(int)value;
- (int)getBrowserPreviewSizeValue;
- (void)setPreviewGenerationSizeValue:(int)value;
- (int)getPreviewGenerationSizeValue;
- (void)setSeparatePreviewCheckboxValue:(BOOL)value;
- (BOOL)getSeparatePreviewCheckboxValue;

- (void)setFileListWidth:(int)value;
- (int)getFileListWidth;
- (int)getFileListFontHeight;
- (NSFont *)getFileListFont;
- (void)setFileListFont:(NSFont *)font;

- (void)setImageOutlineThickness:(int)thickness;
- (int)imageOutlineThickness;

- (void)setOpenInAppRadioValue:(int)value;
- (int)getOpenInAppRadioValue;
- (BOOL)setOpenInAppFile:(GBFile *)file;
- (GBFile *)getOpenInAppFile;
- (NSString *)getOpenInAppFileName;

- (void)setOpenImagesExternally:(BOOL)value;
- (BOOL)openImagesExternally;

- (void)setInfoColorModelValue:(BOOL)value;
- (BOOL)getInfoColorModelValue;
- (void)setInfoMegapixelsValue:(BOOL)value;
- (BOOL)getInfoMegapixelsValue;
- (void)setInfoICCValue:(BOOL)value;
- (BOOL)getInfoICCValue;
- (void)setInfoDimensionsValue:(BOOL)value;
- (BOOL)getInfoDimensionsValue;
- (void)setInfoFileNameValue:(BOOL)value;
- (BOOL)getInfoFileNameValue;
- (void)setInfoFileSizeValue:(BOOL)value;
- (BOOL)getInfoFileSizeValue;
- (void)setInfoFileTypeValue:(BOOL)value;
- (BOOL)getInfoFileTypeValue;
- (void)setInfoImageSizeValue:(BOOL)value;
- (BOOL)getInfoImageSizeValue;
- (void)setInfoKindValue:(BOOL)value;
- (BOOL)getInfoKindValue;
- (void)setInfoModificationValue:(BOOL)value;
- (BOOL)getInfoModificationValue;
- (void)setInfoCreationValue:(BOOL)value;
- (BOOL)getInfoCreationValue;
- (void)setInfoResolutionValue:(BOOL)value;
- (BOOL)getInfoResolutionValue;

- (BOOL)fileListUsesGenericIcons;
- (void)setFileListUsesGenericIcons:(BOOL)value;

- (void)setStatusString:(NSString *)status;
- (NSString *)getStatusString;

- (void)setToolbarConfiguration:(NSDictionary *)dict;
- (NSDictionary *)getToolbarConfiguration;
- (void)setToolbarFilesDict:(NSDictionary *)dict;
- (NSDictionary *)getToolbarFilesDict;


// Persistent storage
    // Saving information to persistent storage:
- (void)convertToDictionary:(CFMutableDictionaryRef)dictionary;

    // Loading information from persistent storage:
- (void)restoreFromDictionary:(CFDictionaryRef)dictionary;

    // Autosaving stuff that doesn't update doc-edited
- (void)autosaveToFile:(NSString *)file;
- (void)autosaveToDictionary:(CFMutableDictionaryRef)dictionary;

    // Getting the settings in a dictionary
- (CFMutableDictionaryRef)prefsDict;

@end

extern NSString *GBPreviewAutoIfDiffValueChangedNotification;
extern NSString *GBFileListPathChangedNotification;
extern NSString *GBFileListPathResetNotification;

extern NSString *GBThumbnailQualityChangedNotification;

extern NSString *GBOpenOptionsValueChangedNotification;
extern NSString *GBOpenSizeOptionsValueChangedNotification;
extern NSString *GBViewFontChangedNotification;
extern NSString *GBBrowserPreviewSizeValueChangedNotification;
extern NSString *GBPreviewGenerationSizeValueChangedNotification;
extern NSString *GBSeparatePreviewCheckboxValueChangedNotification;
extern NSString *GBOpenInAppRadioValueChangedNotification;
extern NSString *GBOpenInAppPathValueChangedNotification;
extern NSString *GBOpenInAppNameValueChangedNotification;

extern NSString *GBInfoCreationValueChangedNotification;
extern NSString *GBInfoMegapixelsValueChangedNotification;
extern NSString *GBInfoICCValueChangedNotification;
extern NSString *GBInfoColorModelValueChangedNotification;
extern NSString *GBInfoDimensionsValueChangedNotification;
extern NSString *GBInfoFileNameValueChangedNotification;
extern NSString *GBInfoFileSizeValueChangedNotification;
extern NSString *GBInfoImageSizeValueChangedNotification;
extern NSString *GBInfoKindValueChangedNotification;
extern NSString *GBInfoFileTypeValueChangedNotification;
extern NSString *GBInfoModificationValueChangedNotification;
extern NSString *GBInfoResolutionValueChangedNotification;

extern NSString *GBStatusStringChangedNotification;

extern NSString *GBPrefsWindowFrameStringChangedNotification;
extern NSString *GBBrowserWindowFrameStringChangedNotification;
extern NSString *GBRootFolderNameTextChangedNotification;

extern NSString *GBIconSizeChangedNotification;
extern NSString *GBListFontChangedNotification;
extern NSString *GBFileListAltBGCheckboxChangedNotification;
extern NSString *GBFileListSelectedPathsChangedNotification;

extern NSString *GBPreviewPaneChangedNotification;
extern NSString *GBFileListBackgroundColorChangedNotification;
extern NSString *GBFileListAltBackgroundColorChangedNotification;
extern NSString *GBFileListTextColorChangedNotification;

extern NSString *GBOutlineImagesCheckboxChangedNotification;

extern NSString *GBPreviewCellsNeedRedrawNotification;

extern NSString *GBFileListSortTypeChangedNotification;
extern NSString *GBPreviewsSortTypeChangedNotification;

extern NSString *GBPreviewCellBorderChangedNotification;

extern NSString *GBCellPaddingValueChangedNotification;
extern NSString *GBHorizontalCellSpacingValueChangedNotification;
extern NSString *GBVerticalCellSpacingValueChangedNotification;

extern NSString *GBFileListExpandedItemsChangedNotification;

extern NSString *GBCellBackgroundColorChangedNotification;
extern NSString *GBCellTextColorChangedNotification;
extern NSString *GBCellTextShadowColorChangedNotification;
extern NSString *GBPreviewPaneBackgroundColorChangedNotification;
extern NSString *GBOutlineImagesColorChangedNotification;

extern NSString *GBImageShadowsCheckboxChangedNotification;
extern NSString *GBTextShadowsCheckboxChangedNotification;

extern NSString *GBOutlineImagesThicknessChangedNotification;

extern NSString *GBPreviewSharpenValueChangedNotification;

extern NSString *GBFileListUsesGenericIconsChangedNotification;

//extern NSString *GBLoadPreviewImmediatelyChangedNotification;
extern NSString *GBCreatePreviewOnTheFlyChangedNotification;


extern NSString *toolbarItemNeedsAddingNotification;
extern NSString *toolbarItemClickedNotification;

extern NSString *GBFileListMinimizeChangedNotification;

extern NSString *GBOpenImagesExternallyChangedNotification;

extern NSString *GBImageViewerBackgroundColorChangedNotification;
extern NSString *GBSlideshowBackgroundColorChangedNotification;

extern NSString *GBImageViewerPercentageChangedNotification;
extern NSString *GBSlideshowPercentageChangedNotification;
extern NSString *GBSlideshowDisplayTypeChangedNotification;
extern NSString *GBImageViewerDisplayTypeChangedNotification;

extern NSString *GBImageViewerOpenFullscreenChangedNotification;
extern NSString *GBImageViewerOpenOnLoadChangedNotification;
extern NSString *GBImageViewerRememberPositionChangedNotification;
extern NSString *GBImageViewerScreenOptionsChangedNotification;

extern NSString *GBSlideshowScreenOptionsChangedNotification;

extern NSString *GBSlideshowFolderGroupingChangedNotification;
extern NSString *GBLoopSlideshowTimerChangedNotification;
extern NSString *GBSlideshowSortTypeChangedNotification;
extern NSString *GBShowSlideshowControllerChangedNotification;
extern NSString *GBSlideshowTimerSecondsChangedNotification;
extern NSString *GBUseSlideshowTimerChangedNotification;

extern NSString *GBRecursiveSlideshowChangedNotification;
extern NSString *GBClusterSlideshowFoldersChangedNotification;
extern NSString *GBSlideshowFoldersInMenusChangedNotification;

extern NSString *GBOpenWithItemsChangedNotification;
extern NSString *GBMoveToItemsChangedNotification;

extern NSString *GBFileListAutoExpandChangedNotification;

extern NSString *GBHighQualityThumbnailScalingChangedNotification;
extern NSString *GBOnTheFlyQualityChangedNotification;
extern NSString *GBPreviewPresharpenValueChangedNotification;

extern NSString *GBSlideshowControllerAutohideChangedNotification;

extern NSString *GBRandomSlideshowChangedNotification;

extern NSString *GBSlideshowTextColorChangedNotification;
extern NSString *GBSlideshowFilenamePositionChangedNotification;
extern NSString *GBSlideshowShowFilenameChangedNotification;
extern NSString *GBSlideshowTextFontChangedNotification;

extern NSString *GBSlideshowControllerCollapseChangedNotification;
extern NSString *GBSlideshowControllerFadeChangedNotification;

extern NSString *GBCollapsePreviewGenWindowChangedNotification;
extern NSString *GBManualPreviewGenOnlyIfDifferentChangedNotification;
extern NSString *GBPreviewGenStripsForksChangedNotification;

/*
extern NSString *GBPreviewPaneFiltersChangedNotification;
extern NSString *GBFileListFiltersChangedNotification;
*/

extern NSString *GBSidebarFiltersChangedNotification;
extern NSString *GBThumbnailFiltersChangedNotification;


extern NSString *GBAlignThumbnailsChangedNotification;

extern NSString *GBShowFileCountInFileListChangedNotification;
extern NSString *GBRenameOnEnterOnlyInFileListChangedNotification;
extern NSString *GBRenameOnEnterOnlyInPreviewPaneChangedNotification;
extern NSString *GBThumbnailShadowColorChangedNotification;
extern NSString *GBFileListSpacingChangedNotification;

extern NSString *GBSaveSlideshowChangesChangedNotification;




extern NSString *GBPrefsSavingNotification;
extern NSString *GBPrefsDeallocNotification;


